Como usar o apigee-ssoadminapi.sh

Edge para nuvem privada v4.19.01

O módulo de SSO do Edge é compatível com dois tipos de contas:

  • administrator
  • usuário da máquina (somente SAML)

O utilitário apigee-ssoadminapi.sh permite gerenciar os usuários administradores e de máquina associados ao módulo de SSO do Edge.

Use o utilitário apigee-ssoadminapi.sh para:

  • Ver a lista de usuários administradores/máquinas
  • Adicionar ou excluir usuários administradores/de máquina
  • Mudar a senha de usuários administradores/de máquina

Sobre usuários administradores

É necessário ter uma conta de administrador no módulo de SSO do Edge para gerenciar as propriedades do módulo.

Por padrão, quando você instala o módulo de SSO do Edge, ele cria uma conta de administrador com as seguintes credenciais:

  • username: definido pela propriedade SSO_ADMIN_NAME no arquivo de configuração usado para configurar o módulo de SSO do Edge. O padrão é ssoadmin..
  • password: definida pela propriedade SSO_ADMIN_SECRET no arquivo de configuração usado para configurar o módulo de SSO do Edge.

Sobre usuários de máquina

Um usuário de máquina pode receber tokens OAuth2 sem precisar especificar uma senha. Isso significa que é possível automatizar completamente o processo de obtenção e atualização de tokens OAuth2 usando a API Management do Edge.

Normalmente, os usuários de máquina são usados para:

  • Configurar o portal de serviços para desenvolvedores da Apigee (ou simplesmente o portal) para se comunicar com o Edge
  • Quando o ambiente de desenvolvimento oferece suporte à automação de tarefas comuns, como automação de testes ou integração contínua/implantação contínua (CI/CD).

Para mais informações, consulte Como usar o SAML com tarefas automatizadas.

Como instalar apigee-ssoadminapi.sh

Instale o utilitário apigee-ssoadminapi.sh no nó do servidor de gerenciamento da borda em que você instalou o módulo de SSO da borda. Normalmente, você instala o utilitário apigee-ssoadminapi.sh ao instalar o módulo de SSO do Edge.

Se você ainda não instalou o utilitário apigee-ssoadminapi.sh:

  1. Faça login no nó do servidor de gerenciamento. Esse nó já deve ter o apigee-service instalado, conforme descrito em Instalar o utilitário apigee-setup do Edge.
  2. Instale o utilitário apigee-ssoadminapi.sh usado para gerenciar usuários administradores e de máquina para o módulo de SSO do Edge:
    /opt/apigee/apigee-service/bin/apigee-service apigee-ssoadminapi install
  3. Saia do shell e faça login novamente para adicionar o utilitário apigee-ssoadminapi.sh ao seu caminho.

Como visualizar informações de ajuda para apigee-ssoadminapi.sh

Os comandos disponíveis para o utilitário são:

  • admin add
  • admin delete
  • admin list
  • admin setpassword
  • saml machineuser add
  • saml machineuser delete
  • aaml machineuser list
  • saml machineuser setpassword

É possível ver informações sobre esses comandos no arquivo /opt/apigee/apigee-ssoadminapi/README.md. Além disso, é possível especificar a opção "-h" para cada comando para ver informações de uso.

Por exemplo, o comando a seguir:

apigee-ssoadminapi.sh admin list -h

Retorna:

admin list
  --admin SSOADMIN_CLIENT_NAME      Name of the client having administrative privilege on sso
  --secret SSOADMIN_CLIENT_SECRET   Secret/Password for the client
  --host SSO_HOST                   Hostname of SSO server to connect
  --port SSO_PORT                   Port to use during request
  --ssl SSO_URI_SCHEME              Set to https, defaults to http
  --debug                           Set in debug mode, turns on verbose in curl
  -h                                Displays Help

Como invocar o utilitário apigee-ssoadminapi.sh

É possível invocar o utilitário apigee-ssoadminapi.sh transmitindo todas as propriedades como argumentos de linha de comando ou no modo interativo, respondendo a solicitações.

Por exemplo, para especificar todas as informações necessárias na linha de comando para ver a lista de usuários administradores:

apigee-ssoadminapi.sh admin list --admin ssoadmin --secret Secret123 --host 35.197.94.184

Retorna:

[
  {
    "client_id": "ssoadmin",
    "access_token_validity": 300
  }
]

Se você omitir alguma informação obrigatória, como a senha de administrador, ela será solicitada.

Neste exemplo, você omite os valores de --port e --ssl porque o módulo de SSO do Edge usa os valores padrão de 9099 para --port e http para --ssl. Se a instalação não usar esses padrões, especifique-os:

apigee-ssoadminapi.sh admin list --admin ssoadmin --secret Secret123
  --host 35.197.94.184 --port 9443 --ssl https

Como alternativa, use o formulário interativo em que todas as informações são solicitadas:

apigee-ssoadminapi.sh admin list

Em seguida, você precisa fornecer todas as informações necessárias:

SSO admin name (current): ssoadmin
SSO Admin secret (current):
SSO host: 35.197.94.184